#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_IS_NGTZ_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_IS_NGTZ_HPP_INCLUDED

#include <nt2/predicates/include/functions/scalar/is_ngtz.hpp>

#endif
